@@ -4,23 +4,23 @@ import json
 import numpy as np
 
 
-def load_plot_data(threshold):
+def load_plot_data(path="./phase_analysis", threshold=None):
     res = {}
 
-    res["comp_ch"] = np.load("phase_analysis/data/comp_ch.npy")
-    res["fe_ch"] = np.load("phase_analysis/data/fe_ch.npy")
-    with open("phase_analysis/data/rss_result_fe.json", "r") as f:
+    res["elements"] = np.load(f"{path}/data/elements.npy")
+    res["hull_comp"] = np.load(f"{path}/data/hull_comp.npy")
+    res["hull_e"] = np.load(f"{path}/data/hull_e.npy")
+    with open(f"{path}/data/composition_data.json", "r") as f:
         data = json.load(f)
-    res["rss_result_fe"] = convert_json_to_ndarray(data)
+    res["composition_data"] = convert_json_to_ndarray(data)
 
     res["not_near_ch"] = None
     res["near_ch"] = None
     if threshold is not None:
-        with open(
-            f"phase_analysis/threshold_{threshold}meV/not_near_ch.json", "r"
-        ) as f:
+        thre = float(threshold)
+        with open(f"{path}/threshold_{thre}meV/not_near_ch.json", "r") as f:
             data1 = json.load(f)
-        with open(f"phase_analysis/threshold_{threshold}meV/near_ch.json", "r") as f:
+        with open(f"{path}/threshold_{thre}meV/near_ch.json", "r") as f:
             data2 = json.load(f)
         res["not_near_ch"] = convert_json_to_ndarray(data1)
         res["near_ch"] = convert_json_to_ndarray(data2)
