@@ -4,9 +4,11 @@ def atomic_energy(element):
         "Al": -0.31455471,
         "As": -1.70125462,
         "Au": -0.18494148,
+        "B": -0.09182149,
         "Ba": -0.03101409,
         "Be": -0.03829264,
         "Bi": -1.32456394,
+        "C": -0.15573804,
         "Ca": -0.00669804,
         "Cd": -0.01269252,
         "Cr": -5.43535568,
